==> reactidsk-0.0.33.tgz: package/lib/components/LoadingBox/LoadingBox.js <==
var __rest = (this && this.__rest) || function (s, e) {
    var t = {};
    for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
        t[p] = s[p];
    if (s != null && typeof Object.getOwnPropertySymbols === "function")
        for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) {
            if (e.indexOf(p[i]) < 0 && Object.prototype.propertyIsEnumerable.call(s, p[i]))
                t[p[i]] = s[p[i]];
        }
    return t;
};
import * as React from 'react';
import styled from 'styled-components';
import { CSSTransition } from 'react-transition-group';
import hexRgb from 'hex-rgb';
import { Spinner } from '../../icons/src';
import { BLACK, WHITE } from '../../global/colors';
const spinnerClassName = 'icon-loading';
const StyledContainer = styled('div')({
    position: 'relative',
    paddingBottom: '2px',
    minHeight: '10px',
});
const Innerwrap = styled('div')(({ timeIn = 0, timeOut = 0, backgroundColor = '', backgroundColorOpacity }) => ({
    position: 'absolute',
    height: '100%',
    top: 0,
    right: 0,
    left: 0,
    bottom: 0,
    display: 'flex',
    justifyContent: 'center',
    [`& .${spinnerClassName}`]: {
        position: 'absolute',
        zIndex: 101,
        opacity: 1,
        display: 'block',
        height: '100%',
        maxHeight: 'calc(50vh + 100px)',
        transition: `opacity ${timeIn}ms ease-in-out`,
        willChange: 'opacity',
    },
    '& .overlay': {
        zIndex: 100,
        transition: `background-color ${timeIn}ms ease-in-out`,
        willChange: 'background-color',
        backgroundColor: `rgba(
      ${hexRgb(backgroundColor).red},
      ${hexRgb(backgroundColor).blue},
      ${hexRgb(backgroundColor).green},
      ${backgroundColorOpacity})`,
    },
    '&.fade-enter': {
        '& .overlay': {
            backgroundColor: `rgba(
        ${hexRgb(backgroundColor).red},
        ${hexRgb(backgroundColor).blue},
        ${hexRgb(backgroundColor).green},
        0)`,
            transitionDuration: `${timeIn}ms`,
        },
        [`& .${spinnerClassName}`]: {
            opacity: 0,
            transitionDuration: `${timeIn}ms`,
            transitionDelay: `${timeIn / 2}ms`,
        },
    },
    '&.fade-enter-active': {
        '& .overlay': {
            backgroundColor: `rgba(
        ${hexRgb(backgroundColor).red},
        ${hexRgb(backgroundColor).blue},
        ${hexRgb(backgroundColor).green},
        ${backgroundColorOpacity})`,
            transitionDuration: `${timeIn}ms`,
        },
        [`& .${spinnerClassName}`]: {
            opacity: 1,
            transitionDuration: `${timeIn}ms`,
            transitionDelay: `${timeIn / 2}ms`,
        },
    },
    '&.fade-exit': {
        '& .overlay': {
            backgroundColor: `rgba(
        ${hexRgb(backgroundColor).red},
        ${hexRgb(backgroundColor).blue},
        ${hexRgb(backgroundColor).green},
        ${backgroundColorOpacity})`,
            transitionDuration: `${timeOut}ms`,
        },
        [`& .${spinnerClassName}`]: {
            opacity: 1,
            transitionDuration: `${timeOut}ms`,
        },
    },
    '&.fade-exit-active': {
        '& .overlay': {
            backgroundColor: `rgba(
        ${hexRgb(backgroundColor).red},
        ${hexRgb(backgroundColor).blue},
        ${hexRgb(backgroundColor).green},
        0)`,
            transitionDuration: `${timeOut}ms`,
        },
        [`& .${spinnerClassName}`]: {
            opacity: 0,
            transitionDuration: `${timeOut}ms`,
        },
    },
}));
const Overlay = styled('div')({
    position: 'absolute',
    top: 0,
    right: 0,
    bottom: 0,
    left: 0,
    overflow: 'hidden',
    height: '100%',
    width: '100%',
});
export const LoadingBox = (_a) => {
    var { children, backgroundColor, backgroundColorOpacity, title, loading, spinnerColor, timeIn, timeOut } = _a, props = __rest(_a, ["children", "backgroundColor", "backgroundColorOpacity", "title", "loading", "spinnerColor", "timeIn", "timeOut"]);
    return (React.createElement(StyledContainer, Object.assign({}, props),
        React.createElement(CSSTransition, { addEndListener: (node, done) => {
                node.addEventListener("transitionend", done, false);
            }, timeout: timeOut, classNames: "fade", in: loading, unmountOnExit: true },
            React.createElement(Innerwrap, { backgroundColor: backgroundColor, backgroundColorOpacity: backgroundColorOpacity, timeIn: timeIn, timeOut: timeOut },
                React.createElement(Spinner, { title: title, className: spinnerClassName, fill: spinnerColor, width: "50px", height: "50px" }),
                React.createElement(Overlay, { className: "overlay" }))),
        children));
};
LoadingBox.defaultProps = {
    spinnerColor: BLACK,
    backgroundColor: WHITE,
    backgroundColorOpacity: 0.85,
    title: undefined,
    loading: false,
    timeIn: 800,
    timeOut: 200,
};
LoadingBox.displayName = 'LoadingBox';
export default LoadingBox;

==> reactidsk-0.0.42.tgz: package/lib/components/LoadingBox/LoadingBox.js <==
var __rest = (this && this.__rest) || function (s, e) {
    var t = {};
    for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
        t[p] = s[p];
    if (s != null && typeof Object.getOwnPropertySymbols === "function")
        for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) {
            if (e.indexOf(p[i]) < 0 && Object.prototype.propertyIsEnumerable.call(s, p[i]))
                t[p[i]] = s[p[i]];
        }
    return t;
};
import * as React from 'react';
import styled from 'styled-components';
import { CSSTransition } from 'react-transition-group';
import hexRgb from 'hex-rgb';
import { Spinner } from '../../icons/src';
import { BLACK, WHITE } from '../../global/colors';
const spinnerClassName = 'icon-loading';
const StyledContainer = styled('div')({
    position: 'relative',
    paddingBottom: '2px',
    minHeight: '10px',
});
const Innerwrap = styled('div')(({ timeIn = 0, timeOut = 0, backgroundColor = '', backgroundColorOpacity }) => ({
    position: 'absolute',
    height: '100%',
    top: 0,
    right: 0,
    left: 0,
    bottom: 0,
    display: 'flex',
    justifyContent: 'center',
    [`& .${spinnerClassName}`]: {
        position: 'absolute',
        zIndex: 101,
        opacity: 1,
        display: 'block',
        height: '100%',
        maxHeight: 'calc(50vh + 100px)',
        transition: `opacity ${timeIn}ms ease-in-out`,
        willChange: 'opacity',
    },
    '& .overlay': {
        zIndex: 100,
        transition: `background-color ${timeIn}ms ease-in-out`,
        willChange: 'background-color',
        backgroundColor: `rgba(
      ${hexRgb(backgroundColor).red},
      ${hexRgb(backgroundColor).blue},
      ${hexRgb(backgroundColor).green},
      ${backgroundColorOpacity})`,
    },
    '&.fade-enter': {
        '& .overlay': {
            backgroundColor: `rgba(
        ${hexRgb(backgroundColor).red},
        ${hexRgb(backgroundColor).blue},
        ${hexRgb(backgroundColor).green},
        0)`,
            transitionDuration: `${timeIn}ms`,
        },
        [`& .${spinnerClassName}`]: {
            opacity: 0,
            transitionDuration: `${timeIn}ms`,
            transitionDelay: `${timeIn / 2}ms`,
        },
    },
    '&.fade-enter-active': {
        '& .overlay': {
            backgroundColor: `rgba(
        ${hexRgb(backgroundColor).red},
        ${hexRgb(backgroundColor).blue},
        ${hexRgb(backgroundColor).green},
        ${backgroundColorOpacity})`,
            transitionDuration: `${timeIn}ms`,
        },
        [`& .${spinnerClassName}`]: {
            opacity: 1,
            transitionDuration: `${timeIn}ms`,
            transitionDelay: `${timeIn / 2}ms`,
        },
    },
    '&.fade-exit': {
        '& .overlay': {
            backgroundColor: `rgba(
        ${hexRgb(backgroundColor).red},
        ${hexRgb(backgroundColor).blue},
        ${hexRgb(backgroundColor).green},
        ${backgroundColorOpacity})`,
            transitionDuration: `${timeOut}ms`,
        },
        [`& .${spinnerClassName}`]: {
            opacity: 1,
            transitionDuration: `${timeOut}ms`,
        },
    },
    '&.fade-exit-active': {
        '& .overlay': {
            backgroundColor: `rgba(
        ${hexRgb(backgroundColor).red},
        ${hexRgb(backgroundColor).blue},
        ${hexRgb(backgroundColor).green},
        0)`,
            transitionDuration: `${timeOut}ms`,
        },
        [`& .${spinnerClassName}`]: {
            opacity: 0,
            transitionDuration: `${timeOut}ms`,
        },
    },
}));
const Overlay = styled('div')({
    position: 'absolute',
    top: 0,
    right: 0,
    bottom: 0,
    left: 0,
    overflow: 'hidden',
    height: '100%',
    width: '100%',
});
export const LoadingBox = (_a) => {
    var { children, backgroundColor, backgroundColorOpacity, title, loading, spinnerColor, timeIn, timeOut } = _a, props = __rest(_a, ["children", "backgroundColor", "backgroundColorOpacity", "title", "loading", "spinnerColor", "timeIn", "timeOut"]);
    const nodeRef = React.useRef(null);
    return (React.createElement(StyledContainer, Object.assign({}, props),
        React.createElement(CSSTransition, { nodeRef: nodeRef, addEndListener: (done) => {
                var _a;
                (_a = nodeRef.current) === null || _a === void 0 ? void 0 : _a.addEventListener('transitionend', done, false);
            }, timeout: timeOut, classNames: "fade", in: loading, unmountOnExit: true },
            React.createElement(Innerwrap, { ref: nodeRef, backgroundColor: backgroundColor, backgroundColorOpacity: backgroundColorOpacity, timeIn: timeIn, timeOut: timeOut },
                React.createElement(Spinner, { title: title, className: spinnerClassName, fill: spinnerColor, width: "50px", height: "50px" }),
                React.createElement(Overlay, { className: "overlay" }))),
        children));
};
LoadingBox.defaultProps = {
    spinnerColor: BLACK,
    backgroundColor: WHITE,
    backgroundColorOpacity: 0.85,
    title: undefined,
    loading: false,
    timeIn: 800,
    timeOut: 200,
};
LoadingBox.displayName = 'LoadingBox';
export default LoadingBox;
